> ## Documentation Index
> Fetch the complete documentation index at: https://docs.incredibuild.com/llms.txt
> Use this file to discover all available pages before exploring further.

# Installing Components

Last updated on Dec 14, 2025

Incredibuild is installed in the **/opt/incredibuild** and **/opt/incredibuild/management** directories, however, the data files are stored in the data directory you specify in the installation commands.

## Installation Prerequisites

1. Verify that your machines meet all [operating system](/linux/4.30.0/supported-platforms-tools) and [system](/linux/4.30.0/system-requirements) requirements. Make sure that the required ports are opened, or use the parameters below to modify the ports.

2. Verify that Security-Enhanced Linux (SELinux) is disabled. For details, see [Disabling SELinux](/linux/4.30.0/disable-selinux).

3. If your linux distribution does not have the **bzip2** package, you will need to add it manually.

4. Get the installer file by registering on [our website](https://www.incredibuild.com/free-trial). If you are already a registered customer but you need the installer file, contact [sales@Incredibuild.com](mailto:Sales@Incredibuild.com).

5. Copy the installer file to any machine you want to install Incredibuild on.

6. Running the installer must be done by a user with root user permissions.

## Installation Examples

Modify the examples below depending on the exact name and version of your installation file, as well as modifying parameters to suit your environment:

Install Primary Coordinator with Initiator and Helper Agents

```
sudo ./incredibuild-<version>.run --action install --coordinator enabled --initiator enabled --helper enabled --data-dir <path to installation directory> --accept-eula true
```

Install Initiator and Helper Agent Only

```
sudo ./incredibuild-<version>.run --action install --initiator enabled --helper enabled --data-dir <path to installation directory> --coordinator-machine <DNS name or IP of Primary Coordinator>
```

Install Secondary Coordinator

```
sudo ./incredibuild-<version>.run --action install --secondary-coordinator enabled --data-dir <path to installation directory> --coordinator-machine <DNS name or IP of Primary Coordinator>
```

Install Build Cache Service

```
sudo ./incredibuild-<version>.run --action install --build-cache-service enabled --data-dir <path to installation directory> --coordinator-machine <DNS name or IP of Primary Coordinator>
```

## Full Installation Command List

There are many more parameters that can be used to modify the installation. To display Incredibuild Linux help, use the install command without any parameters.

| Parameters | Description | Possible Values | Dependencies and Notes |
| - | - | - | - |
| **Main Parameters** | | | |
| `--action` | Defines whether you are installing or upgrading. | \{install,upgrade} | This parameter is always required |
| `--coordinator` | Primary Coordinator installation | \{enabled,disabled} | You cannot install a primary and a secondary Coordinator on the same machine |
| `--secondary-coordinator` | Secondary Coordinator installation | \{enabled,disabled} | You cannot install a primary and a secondary Coordinator on the same machine |
| `--initiator` | Initiator Agent installation | \{enabled,disabled} | Can be installed on the same machine as a helper and a Primary Coordinator |
| `--helper` | Helper Agent installation | \{enabled,disabled} | Can be installed on the same machine as an Initiator and a Primary Coordinator |
| `--build-cache-service` | Installs a Build Cache Service that hosts shared Build Cache. | \{enabled,disabled} | Cannot be installed on a machine with a Helper, Initiator, or Coordinator. |
| `--coordinator-machine` | The IP address or hostname of the Primary Coordinator machine. | Must use a static identifier - either a static IP address or a hostname | Required for the installation of an Initiator, Helper, or Secondary Coordinator on a remote machine. It establishes the communication with the Primary Coordinator. <br /> When an Agent is installed with the Coordinator on the same machine, this parameter is not needed. |
| `--data-dir` | The path to the storage directory, where Incredibuild DBs, log files, and helper file cache (for helper machines only) will be stored. | | This parameter must be included in the installation of all components. Incredibuild will automatically create a link to this path. <br /> The storage directory cannot be under: /opt/incredibuild or /etc/incredibuild. <br /> The directory cannot be located on any of the following operating systems: fuse, cifs, smb, vxfs, tmpfs, nfs. <br /> You must have execute permissions on this directory. |
| `--accept-eula` | Only for Primary Coordinator installation. Pre-approves the end user license agreement (EULA). If this is not done, you will be asked to approve the agreement during installation in the command line. | \{true,false} | |
| **Optional Parameters** | | | |
| `--helper-cache-size` | The size of the helper file cache in GB. | Integer | Default is 10. |
| `--build-cache-service-size` | The size of the Build Cache service in GB. | Integer | Default is 100. Only for Build Cache Service machines. |
| `--local-build-cache-size` | The size of the local Build Cache on an Initiator in GB. | Integer | Default is 100. |
| `--license-type` | You can install Initiator and/or Helper Agents on a volatile VM or container that will receive SUVM licenses by using this parameter with the value SUVM. | \{default, SUVM} | This flag can only be used on an Initiator or Helper that does not include a Coordinator, Secondary Coordinator, or the Build Cache Service. |
| `--skip-coordinator-test` | For Agent installations, skip the connectivity test to the Primary Coordinator that is performed by default. | \{true,false} | The test is performed by default and is only skipped if you set this parameter to true. |
| `--disable-telemetry` | Opt out of sending product usage data to Incredibuild. | \{true,false} | False by default |
| **Port Parameters - Optional** | | | |
| `--coordinator-message-transport-port` | Internal TCP port required for communication with the Coordinator. | Integer | Default is 5672. Only for Primary Coordinators. |
| `--coordinator-ui-port` | Modifies the port for accessing the Web Management Console using HTTPS. | Integer | Default is 8000. Only for Primary Coordinators. |
| `--local-http-port` | Modifies the port for accessing the Web Management Console using HTTP. | Integer | Default is 8080. For all machines except Primary Coordinators. |
| `--local-https-port` | Modifies the port for accessing the Web Management Console using HTTPS. | Integer | Default is 8081. For all machines except Primary Coordinators. |
| `--temp-dir` | The temporary location to extract installer files | | |
| `--utility-port` | The Coordinator Utility Port for helper allocation. | Integer between 1-65535 | Default is 9953 |
